<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 */
function optionsframework_option_name() {
	// Change this to use your theme slug
	$option_name = get_option( 'stylesheet' );
	$option_name = preg_replace( "/\W/", "_", strtolower( $option_name ) );
	return $option_name;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'theme-textdomain'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {

	// Test data
	$test_array = array(
		'one' => __( 'One', 'theme-textdomain' ),
		'two' => __( 'Two', 'theme-textdomain' ),
		'three' => __( 'Three', 'theme-textdomain' ),
		'four' => __( 'Four', 'theme-textdomain' ),
		'five' => __( 'Five', 'theme-textdomain' )
	);
	//是否开启SMTP
	$is_smtp_arr = [
		'false'	=>	__( '否', 'theme-textdomain' ),
		'true'	=>	__( '是', 'theme-textdomain' )
	];
	//选择SMTP协议
	$smtp_protocol_arr = [
		'none'	=>	__( '无', 'theme-textdomain' ),
		'ssl'	=>	__( 'SSL', 'theme-textdomain' ),
		'tls'	=>	__( 'TLS', 'theme-textdomain' )
	];


	// Multicheck Array
	$multicheck_array = array(
		'one' => __( 'French Toast', 'theme-textdomain' ),
		'two' => __( 'Pancake', 'theme-textdomain' ),
		'three' => __( 'Omelette', 'theme-textdomain' ),
		'four' => __( 'Crepe', 'theme-textdomain' ),
		'five' => __( 'Waffle', 'theme-textdomain' )
	);

	// Multicheck Defaults
	$multicheck_defaults = array(
		'one' => '1',
		'five' => '1'
	);

	// Background Defaults
	$background_defaults = array(
		'color' => '',
		'image' => '',
		'repeat' => 'repeat',
		'position' => 'top center',
		'attachment'=>'scroll' );

	// Typography Defaults
	$typography_defaults = array(
		'size' => '15px',
		'face' => 'georgia',
		'style' => 'bold',
		'color' => '#bada55' );

	// Typography Options
	$typography_options = array(
		'sizes' => array( '6','12','14','16','20' ),
		'faces' => array( 'Helvetica Neue' => 'Helvetica Neue','Arial' => 'Arial' ),
		'styles' => array( 'normal' => 'Normal','bold' => 'Bold' ),
		'color' => false
	);

	// Pull all the categories into an array
	$options_categories = array();
	$options_categories_obj = get_categories();
	foreach ($options_categories_obj as $category) {
		$options_categories[$category->cat_ID] = $category->cat_name;
	}

	// Pull all tags into an array
	$options_tags = array();
	$options_tags_obj = get_tags();
	foreach ( $options_tags_obj as $tag ) {
		$options_tags[$tag->term_id] = $tag->name;
	}


	// Pull all the pages into an array
	$options_pages = array();
	$options_pages_obj = get_pages( 'sort_column=post_parent,menu_order' );
	$options_pages[''] = 'Select a page:';
	foreach ($options_pages_obj as $page) {
		$options_pages[$page->ID] = $page->post_title;
	}

	// If using image radio buttons, define a directory path
	$imagepath =  get_template_directory_uri() . '/images/';

	$options = array();

	$options[] = array(
		'name' => '基本设置',
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( '网站关键词', 'theme-textdomain' ),
		'desc' => __( '多个关键词请用英文状态下的,号分隔', 'theme-textdomain' ),
		'id' => 'keywords',
		'std' => 'Msimple',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '网站描述', 'theme-textdomain' ),
		'desc' => __( '一般不超过200字', 'theme-textdomain' ),
		'id' => 'description',
		'std' => '本站使用xiaoz.me提供的Msimple主题，风格简约，支持MarkDown写作，WordPress博客主题的极佳选择。',
		'type' => 'textarea',
	);
	$options[] = array(
		'name' => __( '底部版权', 'theme-textdomain' ),
		'desc' => __( '支持HTML代码', 'theme-textdomain' ),
		'id' => 'footer',
		'std' => 'Copyright © 2013 - 2019. Theme by <a title = "Msimple" href = "https://www.xiaoz.me/" target = "_blank">Msimple</a>',
		'type' => 'textarea',
	);
	$options[] = array(
		'name' => __( '图片加速', 'theme-textdomain' ),
		'desc' => __( '替换文章中的图片为CDN地址，请填写CDN加速域名，比如：cdn.xiaoz.me（注意：不需要http://）', 'theme-textdomain' ),
		'id' => 'cdn',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( 'Gravatar头像加速', 'theme-textdomain' ),
		'desc' => __( '替换Gravatar头像为第三方CDN，注意不需要http://', 'theme-textdomain' ),
		'id' => 'gravatar',
		'std' => 'gravatar.loli.net',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '统计代码', 'theme-textdomain' ),
		'desc' => __( '请输入统计代码，注意不需要<script></script>标签，否则会被过滤。', 'theme-textdomain' ),
		'id' => 'analysis',
		'std' => '',
		'type' => 'textarea',
	);
	$options[] = array(
		'name' => '首页设置',
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( '首页推荐的3个选项', 'theme-textdomain' ),
		'desc' => __( '请复制下面的代码来进行修改', 'theme-textdomain' ),
		'id' => 'home_recommend',
		'std' => '<div class="layui-col-lg4">
		<div class = "item">
			<a href="https://imgurl.org/" rel = "nofollow" target = "_blank">
				<p><h2><i class="fa fa-image fa-fw"></i> ImgURL</h2></p>
				<p>开源免费的图床程序</p>
			</a>
		</div>
	</div>
	<div class="layui-col-lg4">
		<div class = "item">
			<div class = "item">
			<a href="https://wget.ovh/" rel = "nofollow" target = "_blank">
				<p><h2><i class="fa fa-windows fa-fw"></i> wget.ovh</h2></p>
				<p>小z博客软件库，只做软件搬运工。</p>
			</a>
		</div>
		</div>
	</div>
	<div class="layui-col-lg4">
		<div class = "item">
			<div class = "item">
			<a href="https://ip.rss.ink/" rel = "nofollow" target = "_blank">
				<p><h2><i class="fa fa-map-marker fa-fw"></i> IPinfo</h2></p>
				<p>聚合多接口的IP地址查询工具</p>
			</a>
		</div>
		</div>
	</div>',
		'type' => 'textarea',
	);
	
	$options[] = array(
		'name' => __( '首页分类目录1', 'theme-textdomain' ),
		'desc' => __( '格式为“分类目录ID|分类目录名|图标名称|颜色”', 'theme-textdomain' ),
		'id' => 'cat1',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '首页分类目录2', 'theme-textdomain' ),
		'desc' => __( '格式为“分类目录ID|分类目录名|图标名称|颜色”', 'theme-textdomain' ),
		'id' => 'cat2',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '首页分类目录3', 'theme-textdomain' ),
		'desc' => __( '格式为“分类目录ID|分类目录名|图标名称|颜色”', 'theme-textdomain' ),
		'id' => 'cat3',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '首页分类目录4', 'theme-textdomain' ),
		'desc' => __( '格式为“分类目录ID|分类目录名|图标名称|颜色”', 'theme-textdomain' ),
		'id' => 'cat4',
		'std' => '',
		'type' => 'text',
	);
	//个人信息
	$options[] = array(
		'name' => '个人信息',
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( '您的头像', 'theme-textdomain' ),
		'desc' => __( '请输入头像URL地址，建议大小为120 * 120', 'theme-textdomain' ),
		'id' => 'avatar',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '您的昵称', 'theme-textdomain' ),
		'desc' => __( '请取个霸气的名字', 'theme-textdomain' ),
		'id' => 'nickname',
		'std' => 'admin',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '所在地区', 'theme-textdomain' ),
		'desc' => __( '用于首页右侧显示', 'theme-textdomain' ),
		'id' => 'region',
		'std' => '火星',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '个人描述', 'theme-textdomain' ),
		'desc' => __( '用于首页右侧显示', 'theme-textdomain' ),
		'id' => 'about_me',
		'std' => '一个帅气的小伙子。',
		'type' => 'textarea',
	);
	$options[] = array(
		'name' => __( 'QQ', 'theme-textdomain' ),
		'desc' => __( '用于首页右侧显示', 'theme-textdomain' ),
		'id' => 'qq',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '微博', 'theme-textdomain' ),
		'desc' => __( '用于首页右侧显示', 'theme-textdomain' ),
		'id' => 'weibo',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( 'Github', 'theme-textdomain' ),
		'desc' => __( '用于首页右侧显示', 'theme-textdomain' ),
		'id' => 'github',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( 'QQ群链接', 'theme-textdomain' ),
		'desc' => __( '用于首页右侧显示', 'theme-textdomain' ),
		'id' => 'qq_group',
		'std' => '',
		'type' => 'text',
	);
	//广告设置
	$options[] = array(
		'name' => '广告设置',
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( '文章页标题下面的广告', 'theme-textdomain' ),
		'desc' => __( '参考如下方式填写，建议尺寸为：800 * 70，请使用HTML格式添加', 'theme-textdomain' ),
		'id' => 'gg6',
		'std' => '',
		'type' => 'textarea',
	);
	$options[] = array(
		'name' => __( '文章页标题下面的一段描述', 'theme-textdomain' ),
		'desc' => __( '没有可不填写', 'theme-textdomain' ),
		'id' => 'single_description',
		'std' => '如需PHP开发、服务器运维，VPS代购等服务，请联系博主QQ:337003006',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '文章页"打赏支持上面的广告"', 'theme-textdomain' ),
		'desc' => __( '填写HTML格式的图片链接，图片建议尺寸为：800 * 70', 'theme-textdomain' ),
		'id' => 'ad_single_bottom',
		'std' => '',
		'type' => 'textarea',
	);
	$options[] = array(
		'name' => __( '打赏支持', 'theme-textdomain' ),
		'desc' => __( '填写一个多合一收款二维码图片地址', 'theme-textdomain' ),
		'id' => 'donate',
		'std' => 'https://imgurl.org/upload/1712/cb349aa4a1b95997.png',
		'type' => 'text',
	);
	//SMTP设置
	$options[] = array(
		'name' => 'SMTP设置',
		'type' => 'heading'
	);
	$options[] = array(
		'name' => __( '发件人', 'theme-textdomain' ),
		'desc' => __( '发件人昵称，如：小z博客', 'theme-textdomain' ),
		'id' => 'smtp_fromname',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( 'SMTP服务器', 'theme-textdomain' ),
		'desc' => __( '填写邮件服务商提供的SMTP服务器地址', 'theme-textdomain' ),
		'id' => 'smtp_host',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( 'SMTP端口', 'theme-textdomain' ),
		'desc' => __( 'SSL协议一般为465端口', 'theme-textdomain' ),
		'id' => 'smtp_port',
		'std' => 465,
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '用户名', 'theme-textdomain' ),
		'desc' => __( '邮箱用户名，比如：xxx@qq.com', 'theme-textdomain' ),
		'id' => 'smtp_username',
		'std' => '',
		'type' => 'text',
	);
	$options[] = array(
		'name' => __( '密码', 'theme-textdomain' ),
		'desc' => __( '填写邮箱SMTP专属密码', 'theme-textdomain' ),
		'id' => 'smtp_password',
		'std' => '',
		'type' => 'password',
	);
	$options[] = array(
		'name' => __( '发件协议', 'theme-textdomain' ),
		'desc' => __( '请选择发件协议', 'theme-textdomain' ),
		'id' => 'smtp_protocol',
		'std' => 'none',
		'type' => 'select',
		'options' => $smtp_protocol_arr
	);
	$options[] = array(
		'name' => __( '是否启用', 'theme-textdomain' ),
		'desc' => __( '', 'theme-textdomain' ),
		'id' => 'is_smtp',
		'std' => 'false',
		'type' => 'radio',
		'options' => $is_smtp_arr
	);
	

	/**官方自带的暂时用不到，先保留吧 */
	/*
	$options[] = array(
		'name' => __( '基本设置', 'theme-textdomain' ),
		'type' => 'heading'
	);


	$options[] = array(
		'name' => __( 'Input Text Mini', 'theme-textdomain' ),
		'desc' => __( 'A mini text input field.', 'theme-textdomain' ),
		'id' => 'example_text_mini',
		'std' => 'Default',
		'class' => 'mini',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Input Text', 'theme-textdomain' ),
		'desc' => __( 'A text input field.', 'theme-textdomain' ),
		'id' => 'example_text',
		'std' => 'Default Value',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Input with Placeholder', 'theme-textdomain' ),
		'desc' => __( 'A text input field with an HTML5 placeholder.', 'theme-textdomain' ),
		'id' => 'example_placeholder',
		'placeholder' => 'Placeholder',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Textarea', 'theme-textdomain' ),
		'desc' => __( 'Textarea description.', 'theme-textdomain' ),
		'id' => 'example_textarea',
		'std' => 'Default Text',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Input Select Small', 'theme-textdomain' ),
		'desc' => __( 'Small Select Box.', 'theme-textdomain' ),
		'id' => 'example_select',
		'std' => 'three',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $test_array
	);

	$options[] = array(
		'name' => __( 'Input Select Wide', 'theme-textdomain' ),
		'desc' => __( 'A wider select box.', 'theme-textdomain' ),
		'id' => 'example_select_wide',
		'std' => 'two',
		'type' => 'select',
		'options' => $test_array
	);

	if ( $options_categories ) {
		$options[] = array(
			'name' => __( 'Select a Category', 'theme-textdomain' ),
			'desc' => __( 'Passed an array of categories with cat_ID and cat_name', 'theme-textdomain' ),
			'id' => 'example_select_categories',
			'type' => 'select',
			'options' => $options_categories
		);
	}

	if ( $options_tags ) {
		$options[] = array(
			'name' => __( 'Select a Tag', 'options_check' ),
			'desc' => __( 'Passed an array of tags with term_id and term_name', 'options_check' ),
			'id' => 'example_select_tags',
			'type' => 'select',
			'options' => $options_tags
		);
	}

	$options[] = array(
		'name' => __( 'Select a Page', 'theme-textdomain' ),
		'desc' => __( 'Passed an pages with ID and post_title', 'theme-textdomain' ),
		'id' => 'example_select_pages',
		'type' => 'select',
		'options' => $options_pages
	);

	$options[] = array(
		'name' => __( 'Input Radio (one)', 'theme-textdomain' ),
		'desc' => __( 'Radio select with default options "one".', 'theme-textdomain' ),
		'id' => 'example_radio',
		'std' => 'one',
		'type' => 'radio',
		'options' => $test_array
	);

	$options[] = array(
		'name' => __( 'Example Info', 'theme-textdomain' ),
		'desc' => __( 'This is just some example information you can put in the panel.', 'theme-textdomain' ),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'Input Checkbox', 'theme-textdomain' ),
		'desc' => __( 'Example checkbox, defaults to true.', 'theme-textdomain' ),
		'id' => 'example_checkbox',
		'std' => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( '广告设置', 'theme-textdomain' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Check to Show a Hidden Text Input', 'theme-textdomain' ),
		'desc' => __( 'Click here and see what happens.', 'theme-textdomain' ),
		'id' => 'example_showhidden',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Hidden Text Input', 'theme-textdomain' ),
		'desc' => __( 'This option is hidden unless activated by a checkbox click.', 'theme-textdomain' ),
		'id' => 'example_text_hidden',
		'std' => 'Hello',
		'class' => 'hidden',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Uploader Test', 'theme-textdomain' ),
		'desc' => __( 'This creates a full size uploader that previews the image.', 'theme-textdomain' ),
		'id' => 'example_uploader',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => "Example Image Selector",
		'desc' => "Images for layout.",
		'id' => "example_images",
		'std' => "2c-l-fixed",
		'type' => "images",
		'options' => array(
			'1col-fixed' => $imagepath . '1col.png',
			'2c-l-fixed' => $imagepath . '2cl.png',
			'2c-r-fixed' => $imagepath . '2cr.png'
		)
	);

	$options[] = array(
		'name' =>  __( 'Example Background', 'theme-textdomain' ),
		'desc' => __( 'Change the background CSS.', 'theme-textdomain' ),
		'id' => 'example_background',
		'std' => $background_defaults,
		'type' => 'background'
	);

	$options[] = array(
		'name' => __( 'Multicheck', 'theme-textdomain' ),
		'desc' => __( 'Multicheck description.', 'theme-textdomain' ),
		'id' => 'example_multicheck',
		'std' => $multicheck_defaults, // These items get checked by default
		'type' => 'multicheck',
		'options' => $multicheck_array
	);

	$options[] = array(
		'name' => __( 'Colorpicker', 'theme-textdomain' ),
		'desc' => __( 'No color selected by default.', 'theme-textdomain' ),
		'id' => 'example_colorpicker',
		'std' => '',
		'type' => 'color'
	);

	$options[] = array( 'name' => __( 'Typography', 'theme-textdomain' ),
		'desc' => __( 'Example typography.', 'theme-textdomain' ),
		'id' => "example_typography",
		'std' => $typography_defaults,
		'type' => 'typography'
	);

	$options[] = array(
		'name' => __( 'Custom Typography', 'theme-textdomain' ),
		'desc' => __( 'Custom typography options.', 'theme-textdomain' ),
		'id' => "custom_typography",
		'std' => $typography_defaults,
		'type' => 'typography',
		'options' => $typography_options
	);

	$options[] = array(
		'name' => __( 'Text Editor', 'theme-textdomain' ),
		'type' => 'heading'
	);
*/

	/**
	 * For $settings options see:
	 * http://codex.wordpress.org/Function_Reference/wp_editor
	 *
	 * 'media_buttons' are not supported as there is no post to attach items to
	 * 'textarea_name' is set by the 'id' you choose
	 */

	$wp_editor_settings = array(
		'wpautop' => true, // Default
		'textarea_rows' => 5,
		'tinymce' => array( 'plugins' => 'wordpress,wplink' )
	);

	// $options[] = array(
	// 	'name' => __( 'Default Text Editor', 'theme-textdomain' ),
	// 	'desc' => sprintf( __( 'You can also pass settings to the editor.  Read more about wp_editor in <a href="%1$s" target="_blank">the WordPress codex</a>', 'theme-textdomain' ), 'http://codex.wordpress.org/Function_Reference/wp_editor' ),
	// 	'id' => 'example_editor',
	// 	'type' => 'editor',
	// 	'settings' => $wp_editor_settings
	// );

	return $options;
}